

class TestPigmenta:
    def test_palettes(self):
        from pigmenta import PALETTES
        assert isinstance(PALETTES, object)

    def test_colors_type(self):
        from pigmenta import PALETTES
        assert isinstance(PALETTES.coffee, list)

    def test_colors_hex(self):
        from pigmenta import PALETTES
        assert isinstance(PALETTES.coffee[0], str)
        assert PALETTES.coffee[0].startswith("#")



# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = 'pigmenta'
copyright = '2025, Crispen Gari'
author = 'Crispen Gari'

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = []

templates_path = ['_templates']
exclude_patterns = []

highlight_language = "python"


def setup(app):
    app.add_css_file("css/custom.css")


html_static_path = ["_static"]

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_theme = "sphinx_rtd_theme"
html_static_path = ['_static']



import json
import os
from collections import defaultdict

this = os.path.dirname(__file__)
COLORS = defaultdict()
with open(os.path.join(this, 'static/colorhunt.json'), 'r') as reader:
    data = json.loads(reader.read())
    for category in data:
        key = list(category.keys())[0]
        items = category[key]
        colors = []
        for item in items:
            colors.extend([color['hex'] for color in  item['colors']])
        COLORS[key] = colors

class PALETTES:
    pastel      = COLORS['pastel']
    vintage     = COLORS['vintage']
    retro       = COLORS['retro']
    neon        = COLORS['neon']
    gold        = COLORS['gold']
    light       = COLORS['light']
    dark        = COLORS['dark']
    warm        = COLORS['warm']
    cold        = COLORS['cold']
    summer      = COLORS['summer']
    fall        = COLORS['fall']
    winter      = COLORS['winter']
    spring      = COLORS['spring']
    happy       = COLORS['happy']
    nature      = COLORS['nature']
    earth       = COLORS['earth']
    night       = COLORS['night']
    space       = COLORS['space']
    rainbow     = COLORS['rainbow']
    gradient    = COLORS['gradient']
    sunset      = COLORS['sunset']
    sky         = COLORS['sky']
    sea         = COLORS['sea']
    kids        = COLORS['kids']
    skin        = COLORS['skin']
    food        = COLORS['food']
    cream       = COLORS['cream']
    coffee      = COLORS['coffee']
    wedding     = COLORS['wedding']
    christmas   = COLORS['christmas']
    halloween   = COLORS['halloween']